# Swifttools python package.

This module presents tools to enable access from Python to some of the web-based
tools supporting the Swift satellite.

In this initial release there is a single module available: [xrt_prods](swifttools/xrt_prods/README.md). This provides
a Python interface to the [tools to analyse XRT data](https://www.swift.ac.uk/user_objects).

